Package: timeSeries
Title: Financial Time Series Objects (Rmetrics)
Version: 4041.111
Authors@R: c(person("Diethelm", "Wuertz", role="aut", comment = "original code")
	   , person("Tobias", "Setz", role = c("aut"), email = "tobias.setz@live.com")
	   , person("Yohan", "Chalabi", role = "aut")
	   , person("Martin","Maechler", role="ctb", email="maechler@stat.math.ethz.ch", comment = c(ORCID = "0000-0002-8685-9910"))
	   , person(given = c("Georgi", "N."), family = "Boshnakov", 
                    role = c("cre", "aut"), email = "georgi.boshnakov@manchester.ac.uk") )
Description: 'S4' classes and various tools for financial time series:
  Basic functions such as scaling and sorting, subsetting,
  mathematical operations and statistical functions.
Depends: R (>= 2.10), timeDate (>= 4041.110), methods
Imports: graphics, grDevices, stats, utils
Suggests: RUnit, robustbase, xts, zoo, PerformanceAnalytics, fTrading
LazyData: yes
License: GPL (>= 2)
URL: https://geobosh.github.io/timeSeriesDoc/ (doc),
        https://r-forge.r-project.org/scm/viewvc.php/pkg/timeSeries/?root=rmetrics
        (devel), https://www.rmetrics.org
BugReports: https://r-forge.r-project.org/projects/rmetrics
NeedsCompilation: no
Packaged: 2024-09-21 13:05:35 UTC; georgi
Author: Diethelm Wuertz [aut] (original code),
  Tobias Setz [aut],
  Yohan Chalabi [aut],
  Martin Maechler [ctb] (<https://orcid.org/0000-0002-8685-9910>),
  Georgi N. Boshnakov [cre, aut]
Maintainer: Georgi N. Boshnakov <georgi.boshnakov@manchester.ac.uk>
Repository: CRAN
Date/Publication: 2024-09-22 10:10:03 UTC
Built: R 4.4.2; ; 2025-10-25 10:26:17 UTC; unix
